.. _ufile_list:

UFileList Class
###############

.. autoclass:: urgap.ufile_list.UFileList
   :members:

   .. automethod:: __init__
   .. automethod:: __setitem__
   .. automethod:: __add__
   .. automethod:: __radd__
   .. automethod:: __iadd__